# ndcpyr

Пакет, создаваемый для работы с данными на платформе Национального центра социально-экономических данных (НЦСЭД).

### Назначение

- Препроцессинг данных.
- Исследовательский анализ данных.

### Примеры использования

```
import ndcpyr

# Коррекция названий переменных в соответствии с PEP8.
ndcpyr.dt_rename_pep(df)  # returns dataframe 

```